@@ -19,8 +19,12 @@ class Action:
 
             if re.search(regex_exp, inp):
                 mymodule = importlib.import_module(import_statement)
-                response = getattr(mymodule, function_name)(inp)
-                return response
+                inp_and_userconfig = {
+                    'inp': inp,
+                    'user_config':user_config
+                }
+                response, _ = getattr(mymodule, function_name)(inp_and_userconfig)
+                return response, _
 
 
 if __name__ == '__main__':
