@@ -1,7 +1,7 @@
 import json
 
 
-def setup_mode(inp=None):
+def setup_mode(inp_and_userconfig=None):
     print("You are in Setup mode, let's setup few things")
     name = input("Enter your name: ")
 
@@ -23,4 +23,4 @@ def setup_mode(inp=None):
 
     with open('configs/user_config.json', 'w') as json_file:
         json.dump(dict_config, json_file, indent=4)
-    return "Setup Completed"
+    return "Setup Completed", dict_config
