@@ -66,6 +66,9 @@ class Jarvis:
         output = "Output from Jarvis"
         self.txt2speech(output)
 
+    def update_user_config(self, new_user_config):
+        self.user_config = new_user_config
+
 
 def start(jarvis_features_config, user_config):
     inp_src = "txt"  # mic / txt
@@ -74,8 +77,12 @@ def start(jarvis_features_config, user_config):
     action_obj = action.Action(jarvis_features_config, user_config)
     while True:
         inp = jarvis_obj.get_user_input(inp_src)
-        output = action_obj.take_action(inp, user_config)
+        output, _ = action_obj.take_action(inp, user_config)
         print(output)
+        print(_)
+        if _ != None:
+            print("Config Updated")
+            jarvis_obj.update_user_config(_)
         jarvis_obj.txt2speech(output)
 
 
